==> jackrabbit_2.10.1.orig.tar.xz: jackrabbit-2.10.1/jackrabbit-jcr-server/src/main/java/org/apache/jackrabbit/server/io/IOListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.server.io;

/**
 * <code>IOListener</code> defines an import/export listener.
 */
public interface IOListener {

    /**
     * The import/export context has been passed to the given <code>IOHandler</code>
     *
     * @param handler
     * @param context
     */
    public void onBegin(IOHandler handler, IOContext context);

    /**
     * The specified <code>IOHandler</code> finished. A boolean flag indicates
     * whether the handler was able to run the import/export.
     *
     * @param handler
     * @param context
     * @param success
     */
    public void onEnd(IOHandler handler, IOContext context, boolean success);

    /**
     * An exception occurred during import/export within the specified
     * <code>IOHandler</code>.
     *
     * @param ioHandler
     * @param context
     * @param e
     */
    public void onError(IOHandler ioHandler, IOContext context, Exception e);
}

==> jackrabbit_2.14.4.orig.tar.xz: jackrabbit-2.14.4/jackrabbit-jcr-server/src/main/java/org/apache/jackrabbit/server/io/IOListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.server.io;

/**
 * <code>IOListener</code> defines an import/export listener.
 */
public interface IOListener {

    /**
     * The import/export context has been passed to the given <code>IOHandler</code>.
     */
    public void onBegin(IOHandler handler, IOContext context);

    /**
     * The specified <code>IOHandler</code> finished. A boolean flag indicates
     * whether the handler was able to run the import/export.
     */
    public void onEnd(IOHandler handler, IOContext context, boolean success);

    /**
     * An exception occurred during import/export within the specified
     * <code>IOHandler</code>.
     */
    public void onError(IOHandler ioHandler, IOContext context, Exception e);
}
